pub struct CatalyzerError(/* private fields */);Expand description
An error type for Catalyzer operations.
This type is a wrapper around various error types that can occur during Catalyzer operations.
For ease of use, you can always use the ? operator to propagate errors.
Implementations
Sourceimpl CatalyzerError
impl CatalyzerError
Sourcepub const RuntimeInitializationError: Self
pub const RuntimeInitializationError: Self
A shortcut for creating a RuntimeInitializationError.
Sourcepub const UnsupportedMethodError: Self
pub const UnsupportedMethodError: Self
A shortcut for creating a UnsupportedMethodError.
Sourcepub const fn new(inner: Inner) -> Self
pub const fn new(inner: Inner) -> Self
Creates a new CatalyzerError from the given inner error.
Sourcepub fn into_inner(self) -> Inner
pub fn into_inner(self) -> Inner
Returns the inner error.